embassy-stm32

Crates

git

Versions

stm32u575oi

Flavors

OCTOSPI2

Struct OCTOSPI2 

pub struct OCTOSPI2 { /* private fields */ }
OCTOSPI2 peripheral

Implementations

Source

impl OCTOSPI2

pub const unsafe fn steal() -> Peri<'static, Self>

Unsafely create an instance of this peripheral out of thin air.

Safety

You must ensure that you’re only using one instance of this type at a time.